@@ -26,6 +26,11 @@
 #ifndef GUESTFS_INTERNAL_H_
 #define GUESTFS_INTERNAL_H_
 
+#ifdef __APPLE__
+#include <crt_externs.h>
+#define environ (*_NSGetEnviron())
+#endif // __APPLE__
+
 #include <stdbool.h>
 #include <assert.h>
 
@@ -210,24 +215,18 @@ enum drive_protocol {
   drive_protocol_file,
   drive_protocol_ftp,
   drive_protocol_ftps,
-  drive_protocol_gluster,
   drive_protocol_http,
   drive_protocol_https,
   drive_protocol_iscsi,
   drive_protocol_nbd,
   drive_protocol_rbd,
-  drive_protocol_sheepdog,
   drive_protocol_ssh,
-  drive_protocol_tftp,
 };
 
 enum drive_transport {
   drive_transport_none = 0,     /* no transport specified */
   drive_transport_tcp,          /* +tcp */
   drive_transport_unix,         /* +unix */
-  /* XXX In theory gluster+rdma could be supported here, but
-   * I have no idea what gluster+rdma URLs would look like.
-   */
 };
 
 struct drive_server {
