@@ -309,7 +309,7 @@ test_qemu_devices (guestfs_h *g, struct qemu_data *data)
 #ifdef MACHINE_TYPE
                            MACHINE_TYPE ","
 #endif
-                           "accel=kvm:tcg");
+                           "accel=kvm:hvf:tcg");
   guestfs_int_cmd_add_arg (cmd, "-device");
   guestfs_int_cmd_add_arg (cmd, "?");
   guestfs_int_cmd_clear_capture_errors (cmd);
@@ -574,7 +574,7 @@ generic_qmp_test (guestfs_h *g, struct qemu_data *data,
 #ifdef MACHINE_TYPE
                                      MACHINE_TYPE ","
 #endif
-                                     "accel=kvm:tcg");
+                                     "accel=kvm:hvf:tcg");
   guestfs_int_cmd_add_string_unquoted (cmd, " -qmp stdio");
   guestfs_int_cmd_clear_capture_errors (cmd);
 
@@ -827,20 +827,6 @@ guestfs_int_drive_source_qemu_param (guestfs_h *g,
     return make_uri (g, "ftps", src->username, src->secret,
                      &src->servers[0], src->u.exportname);
 
-  case drive_protocol_gluster:
-    switch (src->servers[0].transport) {
-    case drive_transport_none:
-      return make_uri (g, "gluster", NULL, NULL,
-                       &src->servers[0], src->u.exportname);
-    case drive_transport_tcp:
-      return make_uri (g, "gluster+tcp", NULL, NULL,
-                       &src->servers[0], src->u.exportname);
-    case drive_transport_unix:
-      return make_uri (g, "gluster+unix", NULL, NULL,
-                       &src->servers[0], NULL);
-    }
-    break;
-
   case drive_protocol_http:
     return make_uri (g, "http", src->username, src->secret,
                      &src->servers[0], src->u.exportname);
@@ -940,21 +926,9 @@ guestfs_int_drive_source_qemu_param (guestfs_h *g,
                           secret ? secret : "");
   }
 
-  case drive_protocol_sheepdog:
-    if (src->nr_servers == 0)
-      return safe_asprintf (g, "sheepdog:%s", src->u.exportname);
-    else                        /* XXX How to pass multiple hosts? */
-      return safe_asprintf (g, "sheepdog:%s:%d:%s",
-                            src->servers[0].u.hostname, src->servers[0].port,
-                            src->u.exportname);
-
   case drive_protocol_ssh:
     return make_uri (g, "ssh", src->username, src->secret,
                      &src->servers[0], src->u.exportname);
-
-  case drive_protocol_tftp:
-    return make_uri (g, "tftp", src->username, src->secret,
-                     &src->servers[0], src->u.exportname);
   }
 
   abort ();
@@ -1023,11 +997,9 @@ guestfs_int_discard_possible (guestfs_h *g, struct drive *drv,
   switch (drv->src.protocol) {
     /* Protocols which support discard. */
   case drive_protocol_file:
-  case drive_protocol_gluster:
   case drive_protocol_iscsi:
   case drive_protocol_nbd:
   case drive_protocol_rbd:
-  case drive_protocol_sheepdog: /* XXX depends on server version */
     break;
 
     /* Protocols which don't support discard. */
@@ -1036,7 +1008,6 @@ guestfs_int_discard_possible (guestfs_h *g, struct drive *drv,
   case drive_protocol_http:
   case drive_protocol_https:
   case drive_protocol_ssh:
-  case drive_protocol_tftp:
     NOT_SUPPORTED (g, -1,
                    _("discard cannot be enabled on this drive: "
                      "protocol ‘%s’ does not support discard"),
